# prelawsql

![Github CI](https://github.com/justmars/prelawsql/actions/workflows/ci.yml/badge.svg)

Attempts uniform underlying functions for reading from and writing to locally downloaded corpus repositories:

1. [Decision](https://github.com/justmars/corpus-decisions)
2. [Statute](https://github.com/justmars/corpus-statutes)
3. [Codifications](https://github.com/justmars/corpus-codifications)

## Config

```sh
source .venv/bin/activate
just dumpenv
pre # show db-based commands
```
